@@ -19,6 +19,7 @@
 #define CODE_H
 
 #include "parserintf.h"
+#include "construct.h"
 
 class FileDef;
 class MemberDef;
@@ -29,24 +30,18 @@ class CCodeParser : public CodeParserInterface
 {
   public:
     CCodeParser();
-    virtual ~CCodeParser();
-    void parseCode(CodeOutputInterface &codeOutIntf,
+   ~CCodeParser() override;
+    NON_COPYABLE(CCodeParser)
+    void parseCode(OutputCodeList &codeOutIntf,
                    const QCString &scopeName,
                    const QCString &input,
                    SrcLangExt lang,
-                   bool isExampleBlock,
-                   const QCString &exampleName=QCString(),
-                   const FileDef *fileDef=0,
-                   int startLine=-1,
-                   int endLine=-1,
-                   bool inlineFragment=FALSE,
-                   const MemberDef *memberDef=0,
-                   bool showLineNumbers=TRUE,
-                   const Definition *searchCtx=0,
-                   bool collectXRefs=TRUE
-                  );
-    void resetCodeParserState();
-    void setStartCodeLine(const bool inp);
+                   bool stripCodeComments,
+                   const CodeParserOptions &options
+                  ) override;
+    void resetCodeParserState() override;
+    void setInsideCodeLine(bool inp);
+    bool insideCodeLine() const;
   private:
     struct Private;
     std::unique_ptr<Private> p;
