@@ -101,13 +101,26 @@ class QCString
 {
   public:
     QCString() = default;
-    explicit QCString( const std::string &s ) : m_rep(s) {}
+    QCString(const QCString &) = default;
+    QCString &operator=(const QCString &) = default;
+    QCString(QCString &&) = default;
+    QCString &operator=(QCString &&) = default;
+   ~QCString() = default;
+
+    QCString( const std::string &s ) : m_rep(s) {}
 
     QCString( std::string &&s) : m_rep(std::move(s)) {}
 
+    QCString &operator=( std::string &&s)
+    {
+      m_rep=std::move(s);
+      return *this;
+    }
+
     QCString( std::string_view sv) : m_rep(sv) {}
 
-    QCString &operator=(std::string_view sv) {
+    QCString &operator=(std::string_view sv)
+    {
       m_rep=sv;
       return *this;
     }
@@ -177,16 +190,18 @@ class QCString
      *  @note the string will be resized to contain \a len characters. The contents of the
      *  string will be lost.
      */
-    void fill( char c, int len = -1 )
+    QCString fill( char c, int len = -1 )
     {
       int l = len==-1 ? static_cast<int>(m_rep.size()) : len;
       m_rep = std::string(l,c);
+      return *this;
     }
 
     QCString &sprintf( const char *format, ... );
 
     int	find( char c, int index=0, bool cs=TRUE ) const;
     int	find( const char *str, int index=0, bool cs=TRUE ) const;
+    int	find( const std::string &str, int index=0, bool cs=TRUE ) const;
     int find( const QCString &str, int index=0, bool cs=TRUE ) const;
 
     int	findRev( char c, int index=-1, bool cs=TRUE) const;
@@ -253,6 +268,8 @@ class QCString
       return QCString(m_rep.substr(start,1+end-start));
     }
 
+    QCString stripLeadingAndTrailingEmptyLines() const;
+
     // Returns a quoted copy of this string, unless it is already quoted.
     // Note that trailing and leading whitespace is removed.
     QCString quoted() const
@@ -493,6 +510,11 @@ class QCString
       return m_rep.rfind(s,0)==0; // looking "backward" starting and ending at index 0
     }
 
+    bool startsWith( const std::string &s) const
+    {
+      return m_rep.rfind(s,0)==0; // looking "backward" starting and ending at index 0
+    }
+
     bool startsWith( const QCString &s ) const
     {
       if (m_rep.empty() || s.isEmpty()) return s.isEmpty();
@@ -506,6 +528,12 @@ class QCString
       return m_rep.length()>=l && m_rep.compare(m_rep.length()-l, l, s, l)==0;
     }
 
+    bool endsWith(const std::string &s) const
+    {
+      size_t l = s.length();
+      return m_rep.length()>=l && m_rep.compare(m_rep.length()-l, l, s)==0;
+    }
+
     bool endsWith(const QCString &s) const
     {
       size_t l = s.length();
