@@ -26,6 +26,8 @@
  * VERSION HISTORY
  * ---------------
  * History:
+ * 20240204:
+ *  - Updated to 1.11.0:
  * 20231107:
  *  - Updated to 1.10.0:
  * 20230817:
@@ -79,7 +81,7 @@
 
 #include "translator_br.h"
 
-class TranslatorPortuguese : public Translator
+class TranslatorPortuguese : public TranslatorAdapter_1_16_0
 {
   public:
 
@@ -189,7 +191,7 @@ class TranslatorPortuguese : public Translator
 
     /*! this is the first part of a sentence that is followed by a class name */
     QCString trThisIsTheListOfAllMembers() override
-    { return "Lista completa de todos os membros de "; }
+    { return "Lista completa de todos os membros de"; }
 
     /*! this is the remainder of the sentence after the class name */
     QCString trIncludingInheritedMembers() override
@@ -394,8 +396,8 @@ class TranslatorPortuguese : public Translator
 
 
     /*! This is used in HTML as the title of index.html. */
-    QCString trDocumentation() override
-    { return "Documentação"; }
+    QCString trDocumentation(const QCString &projName) override
+    { return "Documentação" + (!projName.isEmpty()? " de " + projName : ""); }
 
     /*! This is used in LaTeX as the title of the chapter with the
      * index of all groups.
@@ -698,9 +700,8 @@ class TranslatorPortuguese : public Translator
     QCString trWriteList(int numEntries) override
     {
       QCString result;
-      int i;
       // the inherits list contain `numEntries' classes
-      for (i=0;i<numEntries;i++)
+      for (int i=0;i<numEntries;i++)
       {
         // use generateMarker to generate placeholders for the class links!
         result+=generateMarker(i); // generate marker for entry i in the list
@@ -1233,9 +1234,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trClass(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Classe" : "classe"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "classe", "s");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1244,9 +1243,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trFile(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Ficheiro" : "ficheiro"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "ficheiro", "s");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1255,9 +1252,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trNamespace(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Namespace" : "namespace"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "namespace", "s");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1266,9 +1261,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trGroup(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Grupo" : "grupo"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "grupo", "s");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1277,9 +1270,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trPage(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Página" : "página"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "página", "s");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1288,9 +1279,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trMember(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Membro" : "membro"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "membro", "s");
     }
 
     /*! This is used for translation of the word that will possibly
@@ -1299,9 +1288,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trGlobal(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Globa" : "globa"));
-      result+= singular? "l" : "ais";
-      return result;
+      return createNoun(first_capital, singular, "globa", "is", "l");
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1312,9 +1299,7 @@ class TranslatorPortuguese : public Translator
      *  for the author section in man pages. */
     QCString trAuthor(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Autor" : "autor"));
-      if (!singular) result+="es";
-      return result;
+      return createNoun(first_capital, singular, "autor", "es");
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -1498,7 +1483,7 @@ class TranslatorPortuguese : public Translator
 
     /*! This is used in HTML as the title of page with source code for file filename
      */
-    QCString trSourceFile(QCString& filename) override
+    QCString trSourceFile(const QCString& filename) override
     {
       return  "Código-Fonte de " + filename;
     }
@@ -1540,9 +1525,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trDir(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Diretório" : "diretório"));
-      if (!singular) result+="s";
-      return result;
+      return createNoun(first_capital, singular, "diretório", "s");
     }
 //////////////////////////////////////////////////////////////////////////
 // new since 1.4.1
@@ -1720,9 +1703,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trModule(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Modulo" : "modulo"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "modulo", "s");
     }
     /*! This is put at the bottom of a module documentation page and is
      *  followed by a list of files that were used to generate the page.
@@ -1758,9 +1739,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trType(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Tipo" : "tipo"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "tipo", "s");
     }
     /*! This is used for translation of the word that will possibly
      *  be followed by a single name or by a list of names
@@ -1768,9 +1747,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trSubprogram(bool first_capital, bool singular) override
     {
-      QCString result((first_capital ? "Subprograma" : "subprograma"));
-      if (!singular)  result+="s";
-      return result;
+      return createNoun(first_capital, singular, "subprograma", "s");
     }
 
     /*! C# Type Contraint list */
@@ -1882,10 +1859,10 @@ class TranslatorPortuguese : public Translator
       if (first_capital) return text.mid(0,1).upper()+text.mid(1);
       else return text;
     }
-    QCString trDayPeriod(int period) override
+    QCString trDayPeriod(bool period) override
     {
       static const char *dayPeriod[] = { "AM", "PM" };
-      return dayPeriod[period];
+      return dayPeriod[period?1:0];
     }
 
 //////////////////////////////////////////////////////////////////////////
@@ -2342,9 +2319,7 @@ class TranslatorPortuguese : public Translator
     /** C++20 concept */
     QCString trConcept(bool first_capital, bool singular) override
     {
-        QCString result((first_capital ? "Conceito" : "conceito"));
-        if (!singular) result+="s";
-        return result;
+      return createNoun(first_capital, singular, "conceito", "s");
     }
     /*! used as the title of the HTML page of a C++20 concept page */
     QCString trConceptReference(const QCString &conceptName) override
@@ -2396,7 +2371,7 @@ class TranslatorPortuguese : public Translator
      */
     QCString trFlowchart() override
     {
-        return "Fluxograma: ";
+        return "Fluxograma:";
     }
 
     /*! Please translate also updated body of the method
@@ -2436,7 +2411,7 @@ class TranslatorPortuguese : public Translator
       switch(compType)
       {
         case ClassDef::Class:
-          if (lang == SrcLangExt_Fortran) trType(true,true);
+          if (lang == SrcLangExt::Fortran) trType(true,true);
           else result=trClass(true,true);
           break;
         case ClassDef::Struct:     result="Estrutura"; break;
@@ -2713,7 +2688,14 @@ class TranslatorPortuguese : public Translator
     QCString trCopyToClipboard() override
     {
       return "Copiado para a área de transferência";
-    }    
+    }
+//////////////////////////////////////////////////////////////////////////
+// new since 1.11.0
+//////////////////////////////////////////////////////////////////////////
+    QCString trImportant() override
+    {
+      return "Importante";
+    }
 };
 
 #endif
