@@ -27,7 +27,6 @@
 #include "outputlist.h"
 #include "arguments.h"
 #include "types.h"
-#include "growbuf.h"
 #include "markdown.h"
 #include "VhdlParserTokenManager.h"
 #include "VhdlParserErrorHandler.hpp"
@@ -56,10 +55,10 @@ static EntryList g_instFiles;
 
 struct VHDLOutlineParser::Private
 {
-  void parseVhdlfile(const QCString &fileName,const char* inputBuffer,bool inLine);
+  void parseVhdlfile(const QCString &fileName,const QCString &inputBuffer,bool inLine);
 
-  VHDLOutlineParser      *thisParser = 0;
-  VhdlParser             *vhdlParser = 0;
+  VHDLOutlineParser      *thisParser = nullptr;
+  VhdlParser             *vhdlParser = nullptr;
   CommentScanner          commentScanner;
 
   QCString                yyFileName;
@@ -67,11 +66,11 @@ struct VHDLOutlineParser::Private
   IntVector               lineParse;
   int                     iDocLine      = -1;
   QCString                inputString;
-  Entry*                  gBlock        = 0;
-  Entry*                  previous      = 0;
+  Entry*                  gBlock        = nullptr;
+  Entry*                  previous      = nullptr;
 //-------------------------------------------------------
 
-  Entry*                  oldEntry = 0;
+  Entry*                  oldEntry = nullptr;
   bool                    varr = FALSE;
   QCString                varName;
   EntryList               libUse;
@@ -86,10 +85,9 @@ struct VHDLOutlineParser::Private
 };
 
 void VHDLOutlineParser::Private::parseVhdlfile(const QCString &fileName,
-                                               const char* inputBuffer,bool inLine)
+                                               const QCString &inputBuffer,bool inLine)
 {
-  JAVACC_STRING_TYPE s =inputBuffer;
-  CharStream *stream = new CharStream(s.c_str(), (int)s.size(), 1, 1);
+  CharStream *stream = new CharStream(reinterpret_cast<const JJChar*>(inputBuffer.data()), (int)inputBuffer.size(), 1, 1);
   VhdlParserTokenManager *tokenManager = new VhdlParserTokenManager(stream);
   VhdlTokenManagerErrorHandler *tokErrHandler=new VhdlTokenManagerErrorHandler(fileName.data());
   vhdlParser=new VhdlParser(tokenManager);
@@ -140,6 +138,8 @@ void VHDLOutlineParser::parseInput(const QCString &fileName,const char *fileBuf,
 
   bool inLine = fileName.isEmpty();
 
+  if (!inLine) msg("Parsing file {}...\n",fileName);
+
   p->yyFileName=fileName;
 
   bool xilinx_ucf=isConstraintFile(p->yyFileName,".ucf");
@@ -159,10 +159,9 @@ void VHDLOutlineParser::parseInput(const QCString &fileName,const char *fileBuf,
   }
   p->yyLineNr=1;
   s->current_root=root;
-  s->lastCompound=0;
-  s->lastEntity=0;
-  s->lastEntity=0;
-  p->oldEntry = 0;
+  s->lastCompound=nullptr;
+  s->lastEntity=nullptr;
+  p->oldEntry = nullptr;
   s->current=std::make_shared<Entry>();
   initEntry(s->current.get());
   p->commentScanner.enterFile(fileName,p->yyLineNr);
@@ -175,7 +174,7 @@ void VHDLOutlineParser::parseInput(const QCString &fileName,const char *fileBuf,
   if (!inLine)
   mapLibPackage(root.get());
 
-  p->yyFileName.resize(0);
+  p->yyFileName.clear();
   p->libUse.clear();
 }
 
@@ -184,22 +183,25 @@ void VHDLOutlineParser::lineCount()
   p->yyLineNr++;
 }
 
-void VHDLOutlineParser::lineCount(const char* text)
+void VHDLOutlineParser::lineCount(const QCString &text)
 {
-  for (const char* c=text ; *c ; ++c )
+  if (!text.isEmpty())
   {
-    if (*c == '\n') p->yyLineNr++;
+    for (const char* c=text.data() ; *c ; ++c )
+    {
+      if (*c == '\n') p->yyLineNr++;
+    }
   }
 }
 
 void VHDLOutlineParser::initEntry(Entry *e)
 {
   e->fileName = p->yyFileName;
-  e->lang     = SrcLangExt_VHDL;
+  e->lang     = SrcLangExt::VHDL;
   if (p->str_doc.pending)
   {
     p->str_doc.pending=FALSE;
-    p->oldEntry=0; // prevents endless recursion
+    p->oldEntry=nullptr; // prevents endless recursion
     p->iDocLine=p->str_doc.iDocLine;
     handleCommentBlock(p->str_doc.doc,p->str_doc.brief);
     p->iDocLine=-1;
@@ -211,10 +213,10 @@ void VHDLOutlineParser::newEntry()
 {
   VhdlParser::SharedState *s = &p->shared;
   p->previous = s->current.get();
-  if (s->current->spec==VhdlDocGen::ENTITY ||
-      s->current->spec==VhdlDocGen::PACKAGE ||
-      s->current->spec==VhdlDocGen::ARCHITECTURE ||
-      s->current->spec==VhdlDocGen::PACKAGE_BODY)
+  if (s->current->vhdlSpec==VhdlSpecifier::ENTITY ||
+      s->current->vhdlSpec==VhdlSpecifier::PACKAGE ||
+      s->current->vhdlSpec==VhdlSpecifier::ARCHITECTURE ||
+      s->current->vhdlSpec==VhdlSpecifier::PACKAGE_BODY)
   {
     s->current_root->moveToSubEntryAndRefresh(s->current);
   }
@@ -257,7 +259,7 @@ QCString VHDLOutlineParser::getNameID()
   return QCString().setNum(idCounter++);
 }
 
-void VHDLOutlineParser::handleFlowComment(const char* doc)
+void VHDLOutlineParser::handleFlowComment(const QCString &doc)
 {
   lineCount(doc);
 
@@ -281,8 +283,7 @@ int VHDLOutlineParser::checkInlineCode(QCString &doc)
   {
     if ((int)str.length()<pos) return -1;
     reg::Match match;
-    const std::string s = str.str();
-    if (reg::search(s,match,re,pos)) // match found
+    if (reg::search(str.str(),match,re,pos)) // match found
     {
       return (int)match.position();
     }
@@ -309,7 +310,7 @@ int VHDLOutlineParser::checkInlineCode(QCString &doc)
   p->code = findRe(p->inputString,csRe, p->code + 1);
   int com = p->inputString.find(p->strComment.data());
   int ref = findRe(p->inputString,cendRe, p->code + 1);
-  int len = p->strComment.size();
+  int len = static_cast<int>(p->strComment.size());
 
   int ll = com + len;
   int diff = ref - ll - 3;
@@ -353,11 +354,11 @@ int VHDLOutlineParser::checkInlineCode(QCString &doc)
   gBlock.doc = code;
   gBlock.inbodyDocs = code;
   gBlock.brief = co;
-  gBlock.section = Entry::VARIABLE_SEC;
-  gBlock.spec = VhdlDocGen::MISCELLANEOUS;
+  gBlock.section = EntryType::makeVariable();
+  gBlock.vhdlSpec = VhdlSpecifier::MISCELLANEOUS;
   gBlock.fileName = p->yyFileName;
   gBlock.endBodyLine = p->yyLineNr + val +iLine;
-  gBlock.lang = SrcLangExt_VHDL;
+  gBlock.lang = SrcLangExt::VHDL;
   std::shared_ptr<Entry> compound;
 
   if (s->lastEntity)
@@ -365,7 +366,7 @@ int VHDLOutlineParser::checkInlineCode(QCString &doc)
   else if (s->lastCompound)
     compound = s->lastCompound;
   else
-    compound = 0;
+    compound = nullptr;
 
   if (compound)
   {
@@ -376,7 +377,7 @@ int VHDLOutlineParser::checkInlineCode(QCString &doc)
     gBlock.type = "misc"; // global code like library ieee...
     s->current_root->copyToSubEntry(&gBlock);
   }
-  p->strComment.resize(0);
+  p->strComment.clear();
   return 1;
 }
 
@@ -392,7 +393,7 @@ void VHDLOutlineParser::handleCommentBlock(const QCString &doc1, bool brief)
 
   if (checkMultiComment(doc, p->yyLineNr))
   {
-    p->strComment.resize(0);
+    p->strComment.clear();
     return;
   }
 
@@ -403,6 +404,7 @@ void VHDLOutlineParser::handleCommentBlock(const QCString &doc1, bool brief)
 
   Protection protection = Protection::Public;
   VhdlDocGen::prepareComment(doc);
+  if (doc.isEmpty()) return;
 
   if (p->oldEntry == s->current.get())
   {
@@ -428,6 +430,7 @@ void VHDLOutlineParser::handleCommentBlock(const QCString &doc1, bool brief)
 
   Markdown markdown(p->yyFileName,p->iDocLine);
   int lineNr = p->iDocLine;
+  GuardedSectionStack guards;
   QCString processedDoc = Config_getBool(MARKDOWN_SUPPORT) ? markdown.process(doc,lineNr) : doc;
 
    while (p->commentScanner.parseCommentBlock(
@@ -442,7 +445,9 @@ void VHDLOutlineParser::handleCommentBlock(const QCString &doc1, bool brief)
       protection,
       position,
       needsEntry,
-      Config_getBool(MARKDOWN_SUPPORT)))
+      Config_getBool(MARKDOWN_SUPPORT),
+      &guards
+    ))
   {
     if (needsEntry)
       newEntry();
@@ -453,13 +458,13 @@ void VHDLOutlineParser::handleCommentBlock(const QCString &doc1, bool brief)
     {
       p->varr = FALSE;
       s->current->name = p->varName;
-      s->current->section = Entry::VARIABLEDOC_SEC;
+      s->current->section = EntryType::makeVariableDoc();
       p->varName = "";
     }
     newEntry();
   }
   p->iDocLine = -1;
-  p->strComment.resize(0);
+  p->strComment.clear();
 }
 
 void VHDLOutlineParser::parsePrototype(const QCString &text)
@@ -468,11 +473,11 @@ void VHDLOutlineParser::parsePrototype(const QCString &text)
   p->varr=TRUE;
 }
 
-void VHDLOutlineParser::addCompInst(const char *n, const char* instName, const char* comp,int iLine)
+void VHDLOutlineParser::addCompInst(const QCString &n, const QCString &instName, const QCString &comp,int iLine)
 {
   VhdlParser::SharedState *s = &p->shared;
-  s->current->spec=VhdlDocGen::INSTANTIATION;
-  s->current->section=Entry::VARIABLE_SEC;
+  s->current->vhdlSpec=VhdlSpecifier::INSTANTIATION;
+  s->current->section=EntryType::makeVariable();
   s->current->startLine=iLine;
   s->current->bodyLine=iLine;
   s->current->type=instName;                       // foo:instname e.g proto or work. proto(ttt)
@@ -510,19 +515,18 @@ void VHDLOutlineParser::addCompInst(const char *n, const char* instName, const c
   }
 }
 
-void VHDLOutlineParser::addVhdlType(const char *n,int startLine,int section,
-    uint64_t spec,const char* args,const char* type,Protection prot)
+void VHDLOutlineParser::addVhdlType(const QCString &n,int startLine,EntryType section,
+    VhdlSpecifier spec,const QCString &args,const QCString &type,Protection prot)
 {
   VhdlParser::SharedState *s = &p->shared;
-  QCString name(n);
   if (isFuncProcProced() || VhdlDocGen::getFlowMember())  return;
 
-  if (s->parse_sec==GEN_SEC)
+  if (s->parse_sec==VhdlSection::GEN_SEC)
   {
-    spec= VhdlDocGen::GENERIC;
+    spec=VhdlSpecifier::GENERIC;
   }
 
-  StringVector ql=split(name.str(),",");
+  StringVector ql=split(n.str(),",");
 
   for (size_t u=0;u<ql.size();u++)
   {
@@ -530,7 +534,7 @@ void VHDLOutlineParser::addVhdlType(const char *n,int startLine,int section,
     s->current->startLine=startLine;
     s->current->bodyLine=startLine;
     s->current->section=section;
-    s->current->spec=spec;
+    s->current->vhdlSpec=spec;
     s->current->fileName=p->yyFileName;
     if (s->current->args.isEmpty())
     {
@@ -539,7 +543,7 @@ void VHDLOutlineParser::addVhdlType(const char *n,int startLine,int section,
     s->current->type=type;
     s->current->protection=prot;
 
-    if (!s->lastCompound && (section==Entry::VARIABLE_SEC) &&  (spec == VhdlDocGen::USE || spec == VhdlDocGen::LIBRARY) )
+    if (!s->lastCompound && section.isVariable() &&  (spec == VhdlSpecifier::USE || spec == VhdlSpecifier::LIBRARY) )
     {
       p->libUse.emplace_back(std::make_shared<Entry>(*s->current));
       s->current->reset();
@@ -548,26 +552,24 @@ void VHDLOutlineParser::addVhdlType(const char *n,int startLine,int section,
   }
 }
 
-void VHDLOutlineParser::createFunction(const char *imp,uint64_t spec,const char *fn)
+void VHDLOutlineParser::createFunction(const QCString &impure,VhdlSpecifier spec,const QCString &fname)
 {
   VhdlParser::SharedState *s = &p->shared;
-  QCString impure(imp);
-  QCString fname(fn);
-  s->current->spec=spec;
-  s->current->section=Entry::FUNCTION_SEC;
+  s->current->vhdlSpec=spec;
+  s->current->section=EntryType::makeFunction();
 
   if (impure=="impure" || impure=="pure")
   {
     s->current->exception=impure;
   }
 
-  if (s->parse_sec==GEN_SEC)
+  if (s->parse_sec==VhdlSection::GEN_SEC)
   {
-    s->current->spec= VhdlDocGen::GENERIC;
-    s->current->section=Entry::FUNCTION_SEC;
+    s->current->vhdlSpec=VhdlSpecifier::GENERIC;
+    s->current->section=EntryType::makeFunction();
   }
 
-  if (s->currP==VhdlDocGen::PROCEDURE)
+  if (s->currP==VhdlSpecifier::PROCEDURE)
   {
     s->current->name=impure;
     s->current->exception="";
@@ -577,7 +579,7 @@ void VHDLOutlineParser::createFunction(const char *imp,uint64_t spec,const char
     s->current->name=fname;
   }
 
-  if (spec==VhdlDocGen::PROCESS)
+  if (spec==VhdlSpecifier::PROCESS)
   {
     s->current->args=fname;
     s->current->name=impure;
@@ -599,9 +601,9 @@ void VHDLOutlineParser::createFunction(const char *imp,uint64_t spec,const char
 bool VHDLOutlineParser::isFuncProcProced()
 {
   VhdlParser::SharedState *s = &p->shared;
-  if (s->currP==VhdlDocGen::FUNCTION  ||
-      s->currP==VhdlDocGen::PROCEDURE ||
-      s->currP==VhdlDocGen::PROCESS
+  if (s->currP==VhdlSpecifier::FUNCTION  ||
+      s->currP==VhdlSpecifier::PROCEDURE ||
+      s->currP==VhdlSpecifier::PROCESS
      )
   {
     return TRUE;
@@ -625,34 +627,33 @@ QCString VHDLOutlineParser::popLabel(QCString & q)
 
 
 
-void VHDLOutlineParser::addProto(const char *s1,const char *s2,const char *s3,
-                          const char *s4,const char *s5,const char *s6)
+void VHDLOutlineParser::addProto(const QCString &s1,const QCString &s2,const QCString &s3,
+                                 const QCString &s4,const QCString &s5,const QCString &s6)
 {
   VhdlParser::SharedState *s = &p->shared;
   (void)s5; // avoid unused warning
-  QCString name=s2;
-  StringVector ql=split(name.str(),",");
+  StringVector ql=split(s2.str(),",");
 
   for (const auto &n : ql)
   {
     Argument arg;
     arg.name=n;
-    if (s3)
+    if (!s3.isEmpty())
     {
       arg.type=s3;
     }
     arg.type+=" ";
     arg.type+=s4;
-    if (s6)
+    if (!s6.isEmpty())
     {
       arg.type+=s6;
     }
-    if (s->parse_sec==GEN_SEC && s->param_sec==0)
+    if (s->parse_sec==VhdlSection::GEN_SEC && s->param_sec==VhdlSection::UNKNOWN)
     {
       arg.defval="generic";
     }
 
-    if (s->parse_sec==PARAM_SEC)
+    if (s->parse_sec==VhdlSection::PARAM_SEC)
     {
     //  assert(false);
     }
@@ -746,13 +747,13 @@ void VHDLOutlineParser::createFlow()
   }
   QCString q,ret;
 
-  if (s->currP==VhdlDocGen::FUNCTION)
+  if (s->currP==VhdlSpecifier::FUNCTION)
   {
     q=":function( ";
     FlowChart::alignFuncProc(q,s->tempEntry->argList,true);
     q+=")";
   }
-  else if (s->currP==VhdlDocGen::PROCEDURE)
+  else if (s->currP==VhdlSpecifier::PROCEDURE)
   {
     q=":procedure (";
     FlowChart::alignFuncProc(q,s->tempEntry->argList,false);
@@ -768,11 +769,11 @@ void VHDLOutlineParser::createFlow()
 
   FlowChart::addFlowChart(FlowChart::START_NO,q,QCString());
 
-  if (s->currP==VhdlDocGen::FUNCTION)
+  if (s->currP==VhdlSpecifier::FUNCTION)
   {
     ret="end function ";
   }
-  else if (s->currP==VhdlDocGen::PROCEDURE)
+  else if (s->currP==VhdlSpecifier::PROCEDURE)
   {
     ret="end procedure";
   }
@@ -784,7 +785,7 @@ void VHDLOutlineParser::createFlow()
   FlowChart::addFlowChart(FlowChart::END_NO,ret,QCString());
   //  FlowChart::printFlowList();
   FlowChart::writeFlowChart();
-  s->currP=0;
+  s->currP=VhdlSpecifier::UNKNOWN;
 }
 
 void VHDLOutlineParser::setMultCommentLine()
@@ -848,7 +849,7 @@ void VHDLOutlineParser::error_skipto(int kind)
   {
     p->vhdlParser->getNextToken();  // step to next token
     op=p->vhdlParser->getToken(1);  // get first token
-    if (op==0) break;
+    if (op==nullptr) break;
     //fprintf(stderr,"\n %s",qPrint(t->image));
   } while (op->kind != kind);
   p->vhdlParser->clearError();
@@ -859,15 +860,17 @@ void VHDLOutlineParser::error_skipto(int kind)
   // "if"/"while".
 }
 
-QCString filter2008VhdlComment(const char *s)
+QCString filter2008VhdlComment(const QCString &s)
 {
-  GrowBuf growBuf;
-  const char *p=s+3; // skip /*!
+  if (s.length()<4) return s;
+  QCString result;
+  result.reserve(s.length());
+  const char *p=s.data()+3; // skip /*!
   char c='\0';
   while (*p == ' ' || *p == '\t') p++;
   while ((c=*p++))
   {
-    growBuf.addChar(c);
+    result+=c;
     if (c == '\n')
     {
       // special handling of space followed by * at beginning of line
@@ -878,15 +881,13 @@ QCString filter2008VhdlComment(const char *s)
     }
   }
   // special attention in case */ at end of last line
-  size_t len = growBuf.getPos();
-  if (growBuf.at(len-1) == '/' && growBuf.at(len-2) == '*')
+  size_t len = result.length();
+  if (len>=2 && result[len-1]=='/' && result[len-2]=='*')
   {
     len -= 2;
-    while (growBuf.at(len-1) == '*') len--;
-    c = growBuf.at(len-1);
-    while ((c = growBuf.at(len-1)) == ' ' || c == '\t') len--;
-    growBuf.setPos(len);
+    while (len>0 && result[len-1] == '*') len--;
+    while (len>0 && ((c = result[len-1]) == ' ' || c == '\t')) len--;
+    result.resize(len);
   }
-  growBuf.addChar(0);
-  return growBuf.get();
+  return result;
 }
